@@ -1,8 +1,28 @@
 package ExtUtils::Typemaps::Misc;
-$ExtUtils::Typemaps::Misc::VERSION = '0.001';
+$ExtUtils::Typemaps::Misc::VERSION = '0.002';
 use strict;
 use warnings;
 
+use parent 'ExtUtils::Typemaps';
+
+use ExtUtils::Typemaps::IntObj;
+use ExtUtils::Typemaps::OpaqueObj;
+use ExtUtils::Typemaps::Slurp;
+use ExtUtils::Typemaps::PackedVal;
+
+sub new {
+	my $class = shift;
+
+	my $self = $class->SUPER::new(@_);
+
+	$self->merge(typemap => ExtUtils::Typemaps::IntObj->new);
+	$self->merge(typemap => ExtUtils::Typemaps::OpaqueObj->new);
+	$self->merge(typemap => ExtUtils::Typemaps::Slurp->new);
+	$self->merge(typemap => ExtUtils::Typemaps::PackedVal->new);
+
+	return $self;
+}
+
 1;
 
 # ABSTRACT: A collection of miscelaneous typemap templates
@@ -19,11 +39,11 @@ ExtUtils::Typemaps::Misc - A collection of miscelaneous typemap templates
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 DESCRIPTION
 
-This distribution is a collection of the following typemap bundles:
+This package is an aggregate typemap bundle of all of the bundles in this distribution:
 
 =head2 OpaqueObj
 
@@ -37,6 +57,10 @@ L<ExtUtils::Typemaps::IntObj> is a typemap bundle that contains C<T_INTOBJ> and
 
 L<ExtUtils::Typemaps::Slurp> is a typemap bundle that contains C<T_SLURP_VAL>, C<T_SLURP_VAR> and C<T_SLURP_AV>. These help when slurping all remaining arguments into a single value.
 
+=head2 PackedVal
+
+L<ExtUtils::Typemaps::PackedVal> is a typemap bundle that contains C<T_PACKEDVAL>. It's very similar to C<T_PACKED>, except the output typemap returns the new SV (instead of taking it as an argument).
+
 =head1 AUTHOR
 
 Leon Timmermans <fawaka@gmail.com>
